@@ -24,6 +24,7 @@
 */
 
 #include <stdio.h>
+#include <rpcsvc/nis.h>
 #include "xalloc.h"
 #include "nis_alloc.h"
 
@@ -1170,12 +1171,16 @@ nis_result *nis_copyresult(nis_result *nres, nis_result *res)
     memset(nres, 0, sizeof(*nres));
     
     nres->status = res->status;
-    nres->objects.objects_len = res->objects.objects_len;
-    nres->objects.objects_val = nis_dupobjects(res->objects.objects_val,
-					       res->objects.objects_len);
 
-    if (nres->objects.objects_val == NULL)
-	return NULL;
+    nres->objects.objects_len = res->objects.objects_len;
+    if (res->objects.objects_val != NULL)
+    {
+        nres->objects.objects_val = nis_dupobjects(res->objects.objects_val,
+	  				           res->objects.objects_len);
+
+        if (nres->objects.objects_val == NULL)
+	    return NULL;
+    }
 
     if (nis_copynetobj(&nres->cookie, &res->cookie) == NULL)
 	return NULL;
