@@ -53,37 +53,25 @@ static char *pbuf = NULL;
 #ifdef HAVE_BUGGY_INET_NETWORK
 static int _inet_network(char *cp)
 {
-    int v0, v1, v2, v3;
+    int v[4];
     int res;
-    
-    v0 = v1 = v2 = v3 = 0;
+    int len;
+    int i;
 
-    if (sscanf(cp, "%d.%d.%d.%d", &v0, &v1, &v2, &v3) <= 0)
+    
+    v[0] = v[1] = v[2] = v[3] = 0;
+
+    len = sscanf(cp, "%d.%d.%d.%d", &v[0], &v[1], &v[2], &v[3]);
+    if (len <= 0)
 	return -1;
     
     res = 0;
+
     
-    if (v0|v1|v2|v3)
+    for (i = 0; i < len; i++)
     {
-	res = v0;
-
-	if (v1|v2|v3)
-	{
-	    res <<= 8;
-	    res += v1;
-
-	    if (v2|v3)
-	    {
-		res <<= 8;
-		res += v2;
-
-		if (v3)
-		{
-		    res <<= 8;
-		    res += v3;
-		}
-	    }
-	}
+	res <<= 8;
+	res += v[i];
     }
     
     return res;
@@ -94,6 +82,31 @@ static int _inet_network(char *cp)
 #endif
 #define inet_network _inet_network
 
+
+static struct in_addr _inet_makeaddr(int net, int host)
+{
+    struct in_addr in;
+    long addr;
+
+    
+    addr = net;
+    if (addr != 0)
+    {
+	while ((addr & (0xFF << 24)) == 0)
+	    addr <<= 8;
+    }
+
+    addr |= host;
+
+    in.s_addr = htonl(addr);
+    return in;
+}
+
+#ifdef inet_makeaddr
+#undef inet_makeaddr
+#endif
+#define inet_makeaddr _inet_makeaddr
+
 #endif
 
 static struct netent *netent_parse(char *str, int len)
