@@ -30,11 +30,11 @@
 #include <sys/types.h>
 #include <netdb.h>
 
-extern void yp_setnetent(char *opts);
-extern void yp_endnetent(char *opts);
-extern struct netent *yp_getnetent(char *opts);
-extern struct netent *yp_getnetbyaddr(long net, int type, char *opts);
-extern struct netent *yp_getnetbyname(char *name, char *opts);
+extern void yp_setnetent(int stayopen, void *opts);
+extern void yp_endnetent(void *opts);
+extern struct netent *yp_getnetent(void *opts);
+extern struct netent *yp_getnetbyaddr(long net, int type, void *opts);
+extern struct netent *yp_getnetbyname(char *name, void *opts);
 
 #endif
 
