@@ -31,14 +31,16 @@ extern void print_network(struct netent *);
 int
 main(int argc, char *argv[])
 {
-    struct netent *net;
+   struct netent *net;
+   
+   yp_setnetent(0, NULL);
 
-    yp_setnetent(NULL);
-
-    while ((net = yp_getnetent(NULL)))
-	print_network(net);
-
-    yp_endnetent(NULL);
+   while ((net = yp_getnetent(NULL)))
+   {
+      print_network(net);
+   }
     
-    exit(0);
+   yp_endnetent(NULL);
+   exit(0);
 }
+
