@@ -126,6 +126,13 @@ int main(int argc, char *argv[])
 
     do
     {
+ 	if (len != 0) {
+ 		if (result[len] == '\n') result[len] = '\0';
+ 	}
+ 	if (keylen != 0) {
+ 		if (outkey[keylen] == '\n') outkey[keylen] = '\0';
+ 	}
+ 
 	if (debug_flag)
 	{
 	    printf("Key: len = %d, val = '%.*s'\n", keylen, keylen, outkey);
@@ -134,6 +141,8 @@ int main(int argc, char *argv[])
 
 	if (empty_flag && len == 0)
 	    printf("%.*s\n", keylen, outkey);
+	else if (empty_flag)
+ 	    printf("%.*s %.*s\n", keylen, outkey, len, result);
 	else
 	    printf("%.*s\n", len, result);
 	
